@@ -36,7 +36,7 @@ from openstack.config import cloud_region as cloud_region_mod
 from openstack import exceptions
 from openstack import proxy
 from openstack import utils
-
+from openstack import warnings as os_warnings
 
 DEFAULT_SERVER_AGE = 5
 DEFAULT_PORT_AGE = 5
@@ -303,7 +303,7 @@ class _OpenStackCloudMixin:
             app_name=self.config._app_name,
             app_version=self.config._app_version,
             discovery_cache=self.session._discovery_cache,
-            **params
+            **params,
         )
 
         # Override the cloud name so that logging/location work right
@@ -396,7 +396,7 @@ class _OpenStackCloudMixin:
             request_max_version = '{version}.latest'.format(
                 version=config_major
             )
-            adapter = proxy._ShadeAdapter(
+            adapter = proxy.Proxy(
                 session=self.session,
                 service_type=self.config.get_service_type(service_type),
                 service_name=self.config.get_service_name(service_type),
@@ -414,7 +414,7 @@ class _OpenStackCloudMixin:
             if adapter.get_endpoint():
                 return adapter
 
-        adapter = proxy._ShadeAdapter(
+        adapter = proxy.Proxy(
             session=self.session,
             service_type=self.config.get_service_type(service_type),
             service_name=self.config.get_service_name(service_type),
@@ -433,23 +433,21 @@ class _OpenStackCloudMixin:
         api_major = self._get_major_version_id(api_version)
 
         # If we detect a different version that was configured, warn the user.
-        # shade still knows what to do - but if the user gave us an explicit
-        # version and we couldn't find it, they may want to investigate.
+        # openstacksdk still knows what to do - but if the user gave us an
+        # explicit version and we couldn't find it, they may want to
+        # investigate
         if api_version and config_version and (api_major != config_major):
+            api_version_str = '.'.join([str(f) for f in api_version])
             warning_msg = (
-                '{service_type} is configured for {config_version}'
-                ' but only {api_version} is available. shade is happy'
-                ' with this version, but if you were trying to force an'
-                ' override, that did not happen. You may want to check'
-                ' your cloud, or remove the version specification from'
-                ' your config.'.format(
-                    service_type=service_type,
-                    config_version=config_version,
-                    api_version='.'.join([str(f) for f in api_version]),
-                )
+                f'{service_type} is configured for {config_version} but only '
+                f'{api_version_str} is available. openstacksdk is happy '
+                f'with this version, but if you were trying to force an '
+                f'override, that did not happen. You may want to check '
+                f'your cloud, or remove the version specification from '
+                f'your config.'
             )
             self.log.debug(warning_msg)
-            warnings.warn(warning_msg)
+            warnings.warn(warning_msg, os_warnings.OpenStackDeprecationWarning)
         return adapter
 
     # TODO(shade) This should be replaced with using openstack Connection
@@ -457,7 +455,7 @@ class _OpenStackCloudMixin:
     def _get_raw_client(
         self, service_type, api_version=None, endpoint_override=None
     ):
-        return proxy._ShadeAdapter(
+        return proxy.Proxy(
             session=self.session,
             service_type=self.config.get_service_type(service_type),
             service_name=self.config.get_service_name(service_type),
@@ -617,6 +615,7 @@ class _OpenStackCloudMixin:
             project=self._get_project_info(project_id),
         )
 
+    # TODO(stephenfin): This looks unused? Can we delete it?
     def _get_identity_location(self):
         '''Identity resources do not exist inside of projects.'''
         return utils.Munch(
@@ -628,47 +627,6 @@ class _OpenStackCloudMixin:
             ),
         )
 
-    def _get_project_id_param_dict(self, name_or_id):
-        if name_or_id:
-            project = self.get_project(name_or_id)
-            if not project:
-                return {}
-            if self._is_client_version('identity', 3):
-                return {'default_project_id': project['id']}
-            else:
-                return {'tenant_id': project['id']}
-        else:
-            return {}
-
-    def _get_domain_id_param_dict(self, domain_id):
-        """Get a useable domain."""
-
-        # Keystone v3 requires domains for user and project creation. v2 does
-        # not. However, keystone v2 does not allow user creation by non-admin
-        # users, so we can throw an error to the user that does not need to
-        # mention api versions
-        if self._is_client_version('identity', 3):
-            if not domain_id:
-                raise exc.OpenStackCloudException(
-                    "User or project creation requires an explicit"
-                    " domain_id argument."
-                )
-            else:
-                return {'domain_id': domain_id}
-        else:
-            return {}
-
-    def _get_identity_params(self, domain_id=None, project=None):
-        """Get the domain and project/tenant parameters if needed.
-
-        keystone v2 and v3 are divergent enough that we need to pass or not
-        pass project or tenant_id or domain or nothing in a sane manner.
-        """
-        ret = {}
-        ret.update(self._get_domain_id_param_dict(domain_id))
-        ret.update(self._get_project_id_param_dict(project))
-        return ret
-
     def range_search(self, data, filters):
         """Perform integer range searches across a list of dictionaries.
 
@@ -763,7 +721,7 @@ class _OpenStackCloudMixin:
                 and self._disable_warnings[service_key]
             ):
                 self.log.debug(
-                    "Disabling %(service_key)s entry in catalog" " per config",
+                    "Disabling %(service_key)s entry in catalog per config",
                     {'service_key': service_key},
                 )
                 self._disable_warnings[service_key] = True
@@ -790,7 +748,7 @@ class _OpenStackCloudMixin:
         get_kwargs=None,
         list_args=None,
         list_kwargs=None,
-        **filters
+        **filters,
     ):
         """Search resources
 
